@@ -83,11 +83,16 @@ class MailProcessor(NotifyPlugin):
         self.send_to_admins = send_to_admins
         self.subject_prefix = settings.EMAIL_SUBJECT_PREFIX
 
-    def _send_mail(self, subject, body, html_body=None, project=None, fail_silently=False):
+    def _send_mail(self, subject, body, html_body=None, project=None, fail_silently=False, headers=None):
         send_to = self.get_send_to(project)
         subject_prefix = self.get_option('subject_prefix', project) or self.subject_prefix
 
-        msg = EmailMultiAlternatives('%s%s' % (subject_prefix, subject), body, settings.SERVER_EMAIL, send_to)
+        msg = EmailMultiAlternatives(
+            '%s%s' % (subject_prefix, subject),
+            body,
+            settings.SERVER_EMAIL,
+            send_to,
+            headers=headers)
         if html_body:
             msg.attach_alternative(html_body, "text/html")
         msg.send(fail_silently=fail_silently)
@@ -120,7 +125,7 @@ class MailProcessor(NotifyPlugin):
                 continue
             interface_list.append((interface.get_title(), body))
 
-        subject = '[%s] %s: %s' % (project.name.encode('utf-8'), event.get_level_display().upper(), event.error().encode('utf-8').split('\n')[0])
+        subject = '[%s] %s: %s' % (project.name.encode('utf-8'), event.get_level_display().upper().encode('utf-8'), event.error().encode('utf-8').split('\n')[0])
 
         link = '%s/%s/group/%d/' % (settings.URL_PREFIX, group.project.slug, group.id)
 
@@ -136,6 +141,12 @@ class MailProcessor(NotifyPlugin):
             'link': link,
             'interfaces': interface_list,
         })).run()
+        headers = {
+            'X-Sentry-Logger': event.logger,
+            'X-Sentry-Logger-Level': event.get_level_display(),
+            'X-Sentry-Project': project.name,
+            'X-Sentry-Server': event.server_name,
+        }
 
         self._send_mail(
             subject=subject,
@@ -143,6 +154,7 @@ class MailProcessor(NotifyPlugin):
             html_body=html_body,
             project=project,
             fail_silently=fail_silently,
+            headers=headers,
         )
 
     def get_option(self, key, project=None):
